import Match from '@components/pages/Match';

import Link from 'next/link';
import { FootballData } from '@helpers/FootballData';
import { Statics } from '@helpers/Statics';
import '../../matchdaycard.css';
import leaguesname from '@helpers/leagues.json'
import SharePages from '@components/pages/Share';

import dmetadata from '@metadata.json'

export async function generateMetadata({ params, searchParams }, parent) {
	
	
	const fdata = new FootballData();
	const matchdata = await fdata.getMatch(params.match);

	
	let hname;
	let aname;
	if (matchdata) {
		if (matchdata.homeTeam) {
			if (matchdata.homeTeam.name) {
				hname = matchdata.homeTeam.name ?? false;
			}
		}
		if (matchdata.awayTeam) {
			if (matchdata.awayTeam.name) {
				aname = matchdata.awayTeam.name ?? false;
			}
		}
	}
	let title = dmetadata.name+ 'Make fun from Football';
	if (aname && hname) {
		title = hname +' VS '+aname +' - '+(leaguesname[params.code] ?? "") + ' - '+dmetadata.name;
	}

  return {
    title: title,
    description: 'European Football Leagues Fixtures and Scores | Download & Share Match Cards - '+dmetadata.name,
    openGraph: {
			title: title,
			description: 'European Football Leagues Fixtures and Scores | Download & Share Match Cards - '+dmetadata.name,
      images: [dmetadata.backend+'/storage/'+params.match+'-mdc.png'],
			locale: 'en_US',
			type: 'website',
    },
     robots: {
				index: true,
				follow: true,
				nocache: true,
				googleBot: {
				  index: true,
				  follow: true,
				  noimageindex: true,
				  'max-video-preview': -1,
				  'max-image-preview': 'large',
				  'max-snippet': -1,
				}
			},
			
		twitter: {
		  card: 'summary_large_image',
		  title: title,
		  description: 'European Football Leagues Fixtures and Scores | Download & Share Match Cards - '+dmetadata.name,
		  creator: '@adenlall',
		  images:  [dmetadata.backend+'/storage/'+params.match+'-mdc.png'],
		},
  }
}



async function Page({ params }) {


		const fdata = new FootballData();
		const matchdata = await fdata.getMatch(params.match);


		let color = '#ffbe6f';
		switch ( params.code ) {
			case 'PL':
				color = '#dc8add';
				break;
			case 'PD':
				color = '#ffbe6f';
				break;
			case 'FL1':
				color = '#f9f06b';
				break;
			case 'BL1':
				color = '#f66151';
				break;
			case 'CL':
				color = '#dc8add';
				break;
			case 'SA':
				color = '#a2ffac85';
				break;
			case 'DED':
				color = '#99c1f1';
				break;
			case 'WC':
				color = '#f66151';
				break;
			default:
				color = '#ffbe6f';
				break;
		}

					let bgg = 'yellow';

					if(params.code === 'PL'){
						bgg = 'url("/designs/pl-design.jpeg")';
					} else if (params.code === 'CL') {
						bgg = 'url("/designs/CL.jpg")';
					} else if (params.code === 'PD') {
						bgg = 'url("/designs/PD.svg")';
					} else if (params.code === 'SA') {
						bgg = 'url("/designs/SA.svg")';
					} else if (params.code ==='BL1') {
						bgg = 'radial-gradient(circle, rgb(255, 124, 124) 0%, rgb(255, 86, 86) 14%, rgb(255, 86, 86) 15%, rgb(255, 33, 33) 48%, rgb(255, 255, 255) 100%)';
					} else if (params.code ==='FL1') {
						bgg = 'url("/designs/FL1.svg")';
					} else if (params.code ==='DED') {
						bgg = 'radial-gradient(circle, #99c1f1 0%, #8defff 14%, #bff1ff 15%, #bff1ff 48%, #fff 100%)';
					} else if (params.code === 'WC') {
						bgg = 'radial-gradient(#c7feff 0%, #ffc9c9 14%, #e9ffb9 15%, #b6ffe0 48%, #ffdbc7 100%)';
					}


					let aname="--";
					let ashort="--";
					let alogo="--";
					let hname="--";
					let hshort="--";
					let hlogo="--";
					let mutc="---- -- --";
					let mday="x";
					let mname="-----";
					let memb = "--";

					if (matchdata) {
						if (matchdata.homeTeam) {
							if (matchdata.homeTeam.name) {
								hname = matchdata.homeTeam.name ?? "XX";
							}else{
								hname = "[NOT FOUND]";
							}
							if (matchdata.homeTeam.shortName) {
								hshort = matchdata.homeTeam.shortName ?? "XX";
							}else{
								hshort = "[NOT FOUND]";
							}
							if (matchdata.homeTeam.crest) {
								hlogo = matchdata.homeTeam.crest ?? "XX";
							}else{
								hlogo = "[NOT FOUND]";
							}
						}
						if (matchdata.awayTeam) {
							if (matchdata.awayTeam.name) {
								aname = matchdata.awayTeam.name ?? "XX";
							}else{
								aname = "[NOT FOUND]";
							}
							if (matchdata.awayTeam.shortName) {
								ashort = matchdata.awayTeam.shortName ?? "XX";
							}else{
								ashort = "[NOT FOUND]";
							}
							if (matchdata.awayTeam.crest) {
								alogo = matchdata.awayTeam.crest ?? "XX";
							}else{
								alogo = "[NOT FOUND]";
							}
						}
						if (matchdata.utcDate) {
							mutc = Statics.getTimeFromUTC(matchdata.utcDate);
						}else{
							mutc = '---- -- --';
						}
						if (matchdata.matchday) {
							mday = matchdata.matchday;
						}else{
							mday = 'xx';
						}
						if (matchdata.competition) {
							if (matchdata.competition.name) {
								mname=matchdata.competition.name;
							}else{
								mname="$$$$";
							}
							if (matchdata.competition.emblem) {
								memb = matchdata.competition.emblem;
							}else{
								memb = "--";
							}
						}
					}

		return (
					<div style={{background:bgg, backgroundPosition:'center', backgroundSize:'cover'}}>
								<div className="container m-0 p-4">
										<Link href={`match-day-card/${params.code}?matchday=${matchdata.matchday}`} className="btn">
													Back
										</Link>
								</div>
								<div className="container m-auto sm:mx-auto mx-2">
											<div id={params.match} style={{background:color??'#fff'}} className={`${params.match} flex flex-row flex-nowrap items-center justify-evenly w-auto h-[25em] m-2 rounded-lg p-4`}>
												<div className="h-full" style={{background:`url('${hlogo}')`, backgroundSize:'cover', backgroundPosition:'center'}}>
													<div className="flex flex-col items-center content-center justify-between bg-[#f1fefee0] rounded-lg p-2 h-full w-[7em] min-w-[7em] sm:w-[12em] sm:min-w-[12em]">
														<div className="flex flex-col items-center content-center justify-center">
															<img className="w-full p-2 sm:max-w-[6em] max-w-[5em]" alt={hname} src={hlogo} />
															<h2 className="text-md sm:text-xl font-bold text-center text-black inline-text-1 w-full">{hshort}</h2>
														</div>
														{
															matchdata.score?.fullTime?.home || matchdata.score?.fullTime?.home==0 ? (
															<h4 className="text-xl font-extrabold text-black w-full bg-primary text-center rounded-lg p-2 ">{matchdata.score.fullTime.home}</h4>
															):null
														}
													</div>
												</div>
												<div className="w-full flex flex-col items-center justify-center content-center space-y-2">
														<img className="w-full h-auto sm:max-w-[9em] max-w-[5em]" alt={mname} src={memb ?? ""} />
														<h3 className="text-lg font-bold text-center inline-text-1 ">{mname}</h3>
														<ul className="text-center font-bold">
																<li className="kbd kbd-sm w-full">{mutc ?? "[NOT SET]"}</li>
																<li className="text-lg w-full text-center my-1">matchday : <span className="badge badge-outline kbd-sm">{mday ?? "XX"}</span></li>
																<li className={`badge w-full badge-warnning`}>{matchdata.status ? matchdata.status.replace("_"," ") : "not set yet"}</li>
														</ul>
												</div>

												<div className="h-full" style={{background:`url('${alogo}')`, backgroundSize:'cover', backgroundPosition:'center'}}>
													<div className="flex flex-col items-center content-center justify-between bg-[#f1fefee0] rounded-lg p-2 h-full w-[7em] min-w-[7em] sm:w-[12em] sm:min-w-[12em]">
														<div className="flex flex-col items-center content-center justify-center">
															<img className="w-full p-2 sm:max-w-[6em] max-w-[5em]" alt={aname} src={alogo} />
															<h2 className="text-md sm:text-xl font-bold text-center text-black inline-text-1 w-full">{ashort}</h2>
														</div>
														{
															matchdata.score?.fullTime?.away || matchdata.score?.fullTime?.away==0 ? (
															<h4 className="text-xl font-extrabold text-black w-full bg-primary text-center rounded-lg p-2 ">{matchdata?.score?.fullTime?.away}</h4>
															):null
														}
													</div>
												</div>
											</div>

								</div>
								<SharePages data={matchdata} league={mname} matchday={mday} teams={[hname, aname]} code={params.code} id={params.match} />
					</div>
		);
}
export default Page;
